<h1 align = "center">:rocket: nesc :rocket:</h1>



![image](https://img.shields.io/pypi/v/nesc.svg)
![image](https://img.shields.io/travis/Jie-Yuan/nesc.svg)
![image](https://readthedocs.org/projects/nesc/badge/?version=latest)



---
# Install
```python
pip install -U nesc
```

# Usages

---
# TODO
